pub struct WorkspaceConfig {
pub ttl: Option<Ttl>,
pub auto_prune: bool,
}Expand description
Workspace lifecycle configuration.
Fields
ttl: Option<Ttl>Maximum age of a workspace before it is considered expired.
auto_prune: boolWhen true, expired worktrees are pruned each time open is invoked.