pub fn bare_clone(url: &str, dest: &Path) -> Result<()>Expand description
Clone url as a bare repository into dest.
Also configures remote.origin.fetch so that git fetch populates
refs/remotes/origin/*, then runs an initial fetch.
Errors
Returns an error if the destination directory cannot be created, or if any of the git commands fail.