get_remote_url

Function get_remote_url 

pub fn get_remote_url(repo: &Path, remote: &str) -> Result<String>
Get the URL of a named remote from a git repository.

Errors

Returns an error if git remote get-url fails or the output is not valid UTF-8.