git_fetch

Function git_fetch 

pub fn git_fetch(bare: &Path) -> Result<()>
Fetch the latest refs from origin for a bare clone at bare.

Errors

Returns an error if the git command fails to spawn or exits non-zero.