Module hooks

Module hooks 

Pre/post-open hook execution.

Structs

HookContext
Template variables available to hook scripts.

Functions

run_hook
Render script with ctx, write to a temp file, and execute it. Stdout and stderr are forwarded to the caller’s terminal. A non-zero exit code prints a warning but does not return an error.