pub fn create_local_worktree(
repo: &Path,
dest: &Path,
branch: &str,
branch_exists: bool,
) -> Result<()>Expand description
Create a worktree from a local (non-bare) repository without referencing a remote.
When branch_exists is false a new branch is created from HEAD.
When branch_exists is true the existing local branch is checked out.