pub fn get_remote_url(repo: &Path, remote: &str) -> Result<String>
Get the URL of a named remote from a git repository.
Returns an error if git remote get-url fails or the output is not valid UTF-8.
git remote get-url