Pre/post-open hook execution.
Structs
- Hook
Context - Template variables available to hook scripts.
Functions
- run_
hook - Render
scriptwithctx, write to a temp file, and execute it. Stdout and stderr are forwarded to the caller’s terminal. A non-zero exit code prints a warning but does not return an error.