pub fn augmented_path() -> String
Return the PATH string augmented with common homebrew and system locations.
PATH
On Windows the system PATH is returned unchanged: homebrew paths do not apply and the separator is already ;.
;