pub fn parse(contents: &str) -> Result<RepoConfig, String>Expand description
Parse a .worktree.toml body into a RepoConfig.
Errors
Returns an error string when the document is not valid TOML, when a hook
script is not a string, or when an order value is missing or unknown.